ModelMetadata class abstract

ModelMetadata

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ModelMetadata([void updates(ModelMetadataBuilder b)])
factory

Properties

authors String
Authors of the model
no setter
citation String
Citation of the model
no setter
description String
Model description
no setter
embedder String
Name of the embedder used for the model
no setter
hashCode int
The hash code for this object.
no setterinherited
licence String
Licence of the model
no setter
Link to the model's repository
no setter
modelSize String
Size of the model in MB
no setter
name → BiocentralPredictionModel
Model name
no setter
outputs → BuiltList<ModelOutput>
List of descriptions of model outputs
no setter
protocol Protocol
Protocol of model predictions
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ModelMetadataBuilder)) ModelMetadata
Rebuilds the instance.
inherited
toBuilder() → ModelMetadataBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ModelMetadata>
no setter