PLMEvalTaskInformation class abstract

PLMEvalTaskInformation

Properties:

Annotations
  • @BuiltValue.new()

Constructors

PLMEvalTaskInformation([void updates(PLMEvalTaskInformationBuilder b)])
factory

Properties

description String
Description of the task
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
Name of the task
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PLMEvalTaskInformationBuilder)) PLMEvalTaskInformation
Rebuilds the instance.
inherited
toBuilder() → PLMEvalTaskInformationBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PLMEvalTaskInformation>
no setter